@@ -7,7 +7,7 @@ import cloudpickle
 from botocore.exceptions import ClientError
 from mlops_sdk.config import Config
 from mlops_sdk.mlops_client import MlopsError
-from mlops_sdk.models.mlops_model import MLOpsModel
+from mlops_sdk.ml.mlops_model import MLOpsModel
 
 from pathlib import Path
 import hvac
