@@ -2,7 +2,7 @@ from typing import Any, Dict
 
 import aiohttp
 
-from mlops.config import Config
+from mlops_sdk.config import Config
 
 
 class MlopsError(Exception):
